==> haskell-xml-conduit-1.5.1-7-i686.pkg.tar.xz: usr/share/haskell/register/haskell-xml-conduit.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: xml-conduit
version: 1.5.1
id: xml-conduit-1.5.1-JfbpBnQv96LLUJQ1lKjdTL
key: xml-conduit-1.5.1-JfbpBnQv96LLUJQ1lKjdTL
license: MIT
maintainer: Michael Snoyman <michael@snoyman.com>
stability: Stable
homepage: http://github.com/snoyberg/xml
synopsis: Pure-Haskell utilities for dealing with XML with the conduit package.
description:
    Hackage documentation generation is not reliable. For up to date documentation, please see: <http://www.stackage.org/package/xml-conduit>.
category: XML, Conduit
author: Michael Snoyman <michael@snoyman.com>, Aristid Breitkreuz <aristidb@googlemail.com>
exposed: True
exposed-modules:
    Text.XML.Stream.Parse Text.XML.Stream.Render Text.XML.Unresolved
    Text.XML.Cursor Text.XML.Cursor.Generic Text.XML
hidden-modules: Text.XML.Stream.Token
abi: e6dc4f74b46db1b270bcc093d9c24d9a
trusted: False
import-dirs: /usr/lib/ghc-8.0.2/site-local/xml-conduit-1.5.1
library-dirs: /usr/lib/ghc-8.0.2/site-local/xml-conduit-1.5.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/i386-linux-ghc-8.0.2/xml-conduit-1.5.1
hs-libraries: HSxml-conduit-1.5.1-JfbpBnQv96LLUJQ1lKjdTL
depends:
    attoparsec-0.13.1.0-7xLJO1EwFQpJLBzOR8WqkC base-4.9.1.0
    blaze-builder-0.4.0.2-EbETJDFSQ4b6W7B283dutO
    blaze-html-0.8.1.3-EHw0sCLFL6JKZx2lFkE5O8
    blaze-markup-0.7.1.1-Amik95gvtJH76XeEGEdOV0 bytestring-0.10.8.1
    conduit-1.2.11-GzxQexWP3ouJXox0rAqJ5D
    conduit-extra-1.1.16-5YILVd78SGn9wwYaAO3g7W containers-0.5.7.1
    data-default-0.7.1.1-BNa3MzH41nV77yjS9K2Umq deepseq-1.4.2.0
    monad-control-1.0.2.1-CGbUZWvNENX5nExoNw6Fw5
    resourcet-1.1.9-DJf1ANdxSraDnKUpiOoSOA
    text-1.2.2.2-3ENqlljngKa6xj1Go2fVWq transformers-0.5.2.0
    xml-types-0.3.6-8botxRFeY0wCHMVWLruSRf
haddock-interfaces: /usr/share/doc/haskell-xml-conduit/html/xml-conduit.haddock
haddock-html: /usr/share/doc/haskell-xml-conduit/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-xml-conduit-1.5.1-10-i686.pkg.tar.xz: usr/share/haskell/register/haskell-xml-conduit.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: xml-conduit
version: 1.5.1
id: xml-conduit-1.5.1-8Ene7jQbE5YDKtAYnsRLqh
key: xml-conduit-1.5.1-8Ene7jQbE5YDKtAYnsRLqh
license: MIT
maintainer: Michael Snoyman <michael@snoyman.com>
stability: Stable
homepage: http://github.com/snoyberg/xml
synopsis: Pure-Haskell utilities for dealing with XML with the conduit package.
description:
    Hackage documentation generation is not reliable. For up to date documentation, please see: <http://www.stackage.org/package/xml-conduit>.
category: XML, Conduit
author: Michael Snoyman <michael@snoyman.com>, Aristid Breitkreuz <aristidb@googlemail.com>
exposed: True
exposed-modules:
    Text.XML.Stream.Parse Text.XML.Stream.Render Text.XML.Unresolved
    Text.XML.Cursor Text.XML.Cursor.Generic Text.XML
hidden-modules: Text.XML.Stream.Token
abi: 8e6740350c55de19a827ff1348deb903
trusted: False
import-dirs: /usr/lib/ghc-8.0.2/site-local/xml-conduit-1.5.1
library-dirs: /usr/lib/ghc-8.0.2/site-local/xml-conduit-1.5.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/i386-linux-ghc-8.0.2/xml-conduit-1.5.1
hs-libraries: HSxml-conduit-1.5.1-8Ene7jQbE5YDKtAYnsRLqh
depends:
    attoparsec-0.13.2.0-JkqjYPxw7sG9Iq2J4E1Ndn base-4.9.1.0
    blaze-builder-0.4.0.2-EbETJDFSQ4b6W7B283dutO
    blaze-html-0.9.0.1-6LoDCyuiOhm81hDccML19n
    blaze-markup-0.8.0.0-6wPbGvG5gVcIJK8r30JWLy bytestring-0.10.8.1
    conduit-1.2.11-IZZgx95zXN83i3dNdoRZvV
    conduit-extra-1.1.16-CDLMlreEXPI9wDo2xYmnfQ containers-0.5.7.1
    data-default-0.7.1.1-BNa3MzH41nV77yjS9K2Umq deepseq-1.4.2.0
    monad-control-1.0.2.2-FLdbJMBsCl8Hxe7Woti7SW
    resourcet-1.1.9-AaZCIqnYF9zJKlT6eUxN1Z
    text-1.2.2.2-3ENqlljngKa6xj1Go2fVWq transformers-0.5.2.0
    xml-types-0.3.6-8botxRFeY0wCHMVWLruSRf
haddock-interfaces: /usr/share/doc/haskell-xml-conduit/html/xml-conduit.haddock
haddock-html: /usr/share/doc/haskell-xml-conduit/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
